solage v0.0.1 Solage.Query
Using the available builders, fill the config with the parsed values.
Supported builders:
- Include
- Sort
- Filter
The goal of those builder is to parse the params sent to the Plug and returned useful
data structures so that you can use the resulting jsonapi_query assign to perform things
like association preloading or query sorting in Ecto.